summaryrefslogtreecommitdiff
path: root/debian/patches/100_spelling.patch
blob: fc6894afb0d582e9d9fd463c1c6b29036aeabb73 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
Description: correct some typos
Author: Jörg Frings-Fürst <debian@jff-webhosting.net>
Last-Update: 2014-09-06
---
This patch header follows DEP-3: http://dep.debian.net/deps/dep3/
Index: trunk/spectro/dispcal.c
===================================================================
--- trunk.orig/spectro/dispcal.c
+++ trunk/spectro/dispcal.c
@@ -3059,7 +3059,7 @@ int main(int argc, char *argv[]) {
 			/* Black level adjustment */
 			/* Due to the possibility of the channel offsets not being even, */
 			/* we use the largest of the XYZ values after they have been */
-			/* scaled to be even acording to the white XYZ balance. */
+			/* scaled to be even according to the white XYZ balance. */
 			/* It's safer to set the black level a bit low, and then the */
 			/* calibration curves can bump the low ones up. */
 			if (c == '1') {
Index: trunk/spectro/spotread.c
===================================================================
--- trunk.orig/spectro/spotread.c
+++ trunk/spectro/spotread.c
@@ -483,7 +483,7 @@ int main(int argc, char *argv[]) {
 			/* COM port  */
 			} else if (argv[fa][1] == 'c') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -c");
+				if (na == NULL) usage("Parameter expected following -c");
 				{
 					comport = atoi(na);
 					if (comport < 1 || comport > 40) usage("-c parameter %d out of range",comport);
@@ -492,7 +492,7 @@ int main(int argc, char *argv[]) {
 			/* Display type */
 			} else if (argv[fa][1] == 'y') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -y");
+				if (na == NULL) usage("Parameter expected following -y");
 				dtype = na[0];
 
 #ifndef SALONEINSTLIB
@@ -500,7 +500,7 @@ int main(int argc, char *argv[]) {
 			} else if (argv[fa][1] == 'I') {
 
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -I");
+				if (na == NULL) usage("Parameter expected following -I");
 				if (strcmp(na, "A") == 0
 				 || strcmp(na, "M0") == 0) {
 					tillum_set = spec = 1;
@@ -539,7 +539,7 @@ int main(int argc, char *argv[]) {
 			/* Spectral Illuminant type for XYZ computation */
 			} else if (argv[fa][1] == 'i') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -i");
+				if (na == NULL) usage("Parameter expected following -i");
 				if (strcmp(na, "A") == 0) {
 					illum_set = spec = 1;
 					illum = icxIT_A;
@@ -579,7 +579,7 @@ int main(int argc, char *argv[]) {
 			/* Spectral Observer type */
 			} else if (argv[fa][1] == 'Q') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -Q");
+				if (na == NULL) usage("Parameter expected following -Q");
 				if (strcmp(na, "1931_2") == 0) {			/* Classic 2 degree */
 					obType = icxOT_CIE_1931_2;
 				} else if (strcmp(na, "1964_10") == 0) {	/* Classic 10 degree */
@@ -657,7 +657,7 @@ int main(int argc, char *argv[]) {
 			/* Filter configuration */
 			} else if (argv[fa][1] == 'F') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -F");
+				if (na == NULL) usage("Parameter expected following -F");
 				if (na[0] == 'n' || na[0] == 'N')
 					fe = inst_opt_filter_none;
 				else if (na[0] == 'p' || na[0] == 'P')
@@ -672,7 +672,7 @@ int main(int argc, char *argv[]) {
 			/* Extra filter compensation file */
 			} else if (argv[fa][1] == 'E') {
 				fa = nfa;
-				if (na == NULL) usage("Paramater expected following -E");
+				if (na == NULL) usage("Parameter expected following -E");
 				strncpy(filtername,na,MAXNAMEL-1); filtername[MAXNAMEL-1] = '\000';
 
 			/* Show Yxy */
Index: trunk/spectro/colorhug.c
===================================================================
--- trunk.orig/spectro/colorhug.c
+++ trunk/spectro/colorhug.c
@@ -212,7 +212,7 @@ colorhug_command(colorhug *p,
 
 	a1logd(p->log,8,"colorhug_command: Read %d bytes and %d read\n",xrbytes,rbytes);
 	if (rbytes >= 2) {
-		a1logd(p->log,6,"colorhug_command: recieved cmd '%s' error '%s' args '%s'\n",
+		a1logd(p->log,6,"colorhug_command: received cmd '%s' error '%s' args '%s'\n",
 				inst_desc(buf[1]),
 				colorhug_interp_error((inst *) p, buf[0]),
 				icoms_tohex(buf, rbytes - 2));
Index: trunk/spectro/dtp51.c
===================================================================
--- trunk.orig/spectro/dtp51.c
+++ trunk/spectro/dtp51.c
@@ -678,7 +678,7 @@ dtp51_interp_error(inst *pp, int ec) {
 		case DTP51_INVALID_STEP:
 			return "Invalid step";
 		case DTP51_NO_DATA_AVAILABLE:
-			return "No data availble";
+			return "No data avaialble";
 		case DTP51_LAMP_MARGINAL:
 			return "Lamp marginal";
 		case DTP51_LAMP_FAILURE:
Index: trunk/spectro/dtp92.c
===================================================================
--- trunk.orig/spectro/dtp92.c
+++ trunk/spectro/dtp92.c
@@ -928,7 +928,7 @@ dtp92_interp_error(inst *pp, int ec) {
 		case DTP92_NO_DATA_AVAILABLE:
 			return "No data available";
 		case DTP92_MISSING_PARAMETER:
-			return "Paramter is missing";
+			return "Parameter is missing";
 		case DTP92_CALIBRATION_DENIED:
 			return "Invalid calibration enable code";
 		case DTP92_NEEDS_OFFSET_CAL:
Index: trunk/spectro/hidio.c
===================================================================
--- trunk.orig/spectro/hidio.c
+++ trunk/spectro/hidio.c
@@ -739,7 +739,7 @@ icoms_hid_read(icoms *p,
 	{
 		unsigned char *rbuf2;
 
-		/* Create a copy of the data recieved with one more byte */
+		/* Create a copy of the data received with one more byte */
 		if ((rbuf2 = malloc(bsize + 1)) == NULL) {
 			a1loge(p->log, ICOM_SYS, "icoms_hid_read: malloc failed\n");
 			return ICOM_SYS;
Index: trunk/spectro/huey.c
===================================================================
--- trunk.orig/spectro/huey.c
+++ trunk/spectro/huey.c
@@ -81,7 +81,7 @@ static int icoms2huey_err(int se, int to
 /* i1Display command codes */
 /* B = byte (8bit), S = short (16bit), W = word (32bit), A = string */
 /* U = unused byte, - = no arguments/results */
-/* The is a 7 byte command buffer and 6 response recieve buffer. */
+/* The is a 7 byte command buffer and 6 response receive buffer. */
 /* :2 means the read is from a second 8 byte ep x81 read. */
 /* cbuf[-] is command byte */
 /* rbuf[-2] is continuation byte */
Index: trunk/spectro/i1pro_imp.c
===================================================================
--- trunk.orig/spectro/i1pro_imp.c
+++ trunk/spectro/i1pro_imp.c
@@ -3757,7 +3757,7 @@ i1pro_code i1pro_restore_refspot_cal(i1p
 		return I1PRO_OK;
 	}
 
-	/* We've sucessfully restored the dark calibration */
+	/* We've successfully restored the dark calibration */
 	s->dark_valid = 1;
 	s->ddate = m->caldate;
 
@@ -3802,7 +3802,7 @@ i1pro_code i1pro_restore_refspot_cal(i1p
 		return I1PRO_OK;
 	}
 
-	/* We've sucessfully restored the calibration */
+	/* We've successfully restored the calibration */
 	s->cal_valid = 1;
 	s->cfdate = m->caldate;
 
Index: trunk/spectro/madvrwin.c
===================================================================
--- trunk.orig/spectro/madvrwin.c
+++ trunk/spectro/madvrwin.c
@@ -602,7 +602,7 @@ int ii = 0;
 	}
 #endif
 
-	debugr("new_madvrwin: return sucessfully\n");
+	debugr("new_madvrwin: return successfully\n");
 
 	return p;
 }
Index: trunk/spectro/ss.c
===================================================================
--- trunk.orig/spectro/ss.c
+++ trunk/spectro/ss.c
@@ -1786,7 +1786,7 @@ ss_interp_error(inst *pp, int ec) {
 		case ss_et_BadHexEncoding:
 			return "Message received from instrument has bad Hex encoding";
 		case ss_et_RecBufferOverun:
-			return "Message received from instrument would overflow recieve buffer";
+			return "Message received from instrument would overflow receive buffer";
 		default:
 			return "Unknown error code";
 	}
Index: trunk/spectro/ss_imp.c
===================================================================
--- trunk.orig/spectro/ss_imp.c
+++ trunk/spectro/ss_imp.c
@@ -216,7 +216,7 @@ static int h2b(ss *p, char c) {
 	return 0;
 }
 
-/* Return the first enum from the recieve buffer without removing it. */
+/* Return the first enum from the receive buffer without removing it. */
 int ss_peek_ans(ss *p) {
 	int rv;
 
Index: trunk/spectro/webwin.c
===================================================================
--- trunk.orig/spectro/webwin.c
+++ trunk/spectro/webwin.c
@@ -408,7 +408,7 @@ int ddebug						/* >0 to print debug sta
 		msec_sleep(50);
 	}
 
-	debugr("new_webwin: return sucessfully\n");
+	debugr("new_webwin: return successfully\n");
 
 	return p;
 }
Index: trunk/xicc/cv.c
===================================================================
--- trunk.orig/xicc/cv.c
+++ trunk/xicc/cv.c
@@ -101,7 +101,7 @@ main(int argc, char *argv[]) {
 
 	printf("There are %d parameters:\n",np); fflush(stdout);
 	for (i = 0; i < np; i++) {
-		printf("Paramter %d = %f\n",i, params[i]); fflush(stdout);
+		printf("Parameter %d = %f\n",i, params[i]); fflush(stdout);
 	}
 
 	/* Display the result */
Index: trunk/spectro/ss_imp.h
===================================================================
--- trunk.orig/spectro/ss_imp.h
+++ trunk/spectro/ss_imp.h
@@ -720,7 +720,7 @@ void ss_add_string(struct _ss *p, char *
 /* - - - - - - - - - - - - - - - - - - - - - */
 /* ANSWER: */
 
-/* Return the first enum from the recieve buffer without removing it. */
+/* Return the first enum from the receive buffer without removing it. */
 int ss_peek_ans(struct _ss *p);
 
 /* Remove a Spectrolino answer enum from the revieve buffer, */
Index: trunk/imdi/cctiff.c
===================================================================
--- trunk.orig/imdi/cctiff.c
+++ trunk/imdi/cctiff.c
@@ -36,7 +36,7 @@
 	Add flag to ignore inkname mismatches.
 
 
-	Should add support for transfering any extra alpha
+	Should add support for transferring any extra alpha
 	planes from input to output, rather than simply ignoring them.
 
 
@@ -1942,11 +1942,11 @@ main(int argc, char *argv[]) {
 
 		if (wh != NULL) {
 			printf("Output TIFF file '%s'\n",out_name);
-			printf("Ouput raster file ICC colorspace is %s\n",icm2str(icmColorSpaceSignature,su.outs));
+			printf("Output raster file ICC colorspace is %s\n",icm2str(icmColorSpaceSignature,su.outs));
 			printf("Output TIFF file photometric is %s\n",Photometric2str(wphotometric));
 		} else {
 			printf("Output JPEG file '%s'\n",out_name);
-			printf("Ouput raster file ICC colorspace is %s\n",icm2str(icmColorSpaceSignature,su.outs));
+			printf("Output raster file ICC colorspace is %s\n",icm2str(icmColorSpaceSignature,su.outs));
 			printf("Output JPEG file colorspace is %s\n",JPEG_cspace2str(wj.jpeg_color_space));
 			if (wdesc != NULL)
 				printf("Output raster file description: '%s'\n",wdesc);
Index: trunk/imdi/imdi.h
===================================================================
--- trunk.orig/imdi/imdi.h
+++ trunk/imdi/imdi.h
@@ -38,7 +38,7 @@ struct _imdi {
 
 	/* Note that once an imdi is created, multiple can call interp() without */
 	/* interfering with each other, allowing parallel execution. */
-	void (*interp)(struct _imdi *s, void **outp, int outst,		/* Ouput pointers and stride */
+	void (*interp)(struct _imdi *s, void **outp, int outst,		/* Output pointers and stride */
 	                                void **inp, int inst,		/* Input pointers and stride */
 	                                unsigned int npixels);		/* Number of pixels */
 
Index: trunk/spectro/munki_imp.c
===================================================================
--- trunk.orig/spectro/munki_imp.c
+++ trunk/spectro/munki_imp.c
@@ -6391,7 +6391,7 @@ munki_code munki_create_hr(munki *p, int
 	int i, j, jj, k, cx, sx;
 	munki_fc coeff[40][16];	/* Existing filter cooefficients */
 	int nwav1;					/* Number of filters */
-	double wl_short1, wl_long1;	/* Ouput wavelength of first and last filters */
+	double wl_short1, wl_long1;	/* Output wavelength of first and last filters */
 	double wl_step1;
 	munki_xp xp[41];			/* Crossover points each side of filter */
 	munki_code ev = MUNKI_OK;
Index: trunk/target/printtarg.c
===================================================================
--- trunk.orig/target/printtarg.c
+++ trunk/target/printtarg.c
@@ -2953,7 +2953,7 @@ char *argv[];
 	double sscale = 1.0;	/* Spacer size scale */
 	int rand = 1;
 	int qbits = 0;			/* Quantization bits */
-	int oft = 0;			/* Ouput File type, 0 = PS, 1 = EPS , 2 = TIFF */
+	int oft = 0;			/* Output File type, 0 = PS, 1 = EPS , 2 = TIFF */
 	int nocups = 0;			/* Supress CUPS PS/EPS job ticket */
 	depth2d tiffdpth = bpc8_2d;	/* TIFF pixel depth */
 	double tiffres = 100.0;	/* TIFF resolution in DPI */
Index: trunk/gamut/nearsmth.c
===================================================================
--- trunk.orig/gamut/nearsmth.c
+++ trunk/gamut/nearsmth.c
@@ -261,7 +261,7 @@ double dxratio		/* Depth expansion ratio
 	double va, vr = 0.0, vl, vd, vv = 0.0;
 
 	/* Absolute, Delta E^2 between test point and destination closest */
-	/* aodv is already positioned acording to the LCh weights, */
+	/* aodv is already positioned according to the LCh weights, */
 	/* so weight as per average of these */
 	a_o = w->a.o;
 	va = wdesq(dtp, aodv, a_o, a_o, a_o, SUM_POW);
@@ -3598,7 +3598,7 @@ static void create_influence_plot(nearsm
 	swdiag = new_rspl(RSPL_NOFLAGS, 3, 3);	/* Allocate 3D -> 3D */
 	swdiag->fit_rspl(swdiag, RSPL_NOFLAGS, fpnts, nmpts, NULL, NULL, gres, NULL, NULL, 1.0, avgdev, NULL);
 
-	/* Now create a plot of the sci_gam with the vertexes colored acording to the */
+	/* Now create a plot of the sci_gam with the vertexes colored according to the */
 	/* diagnostic map. */
 	if ((wrl = new_vrml("sci_gam_wt", 1, vrml_lab)) == NULL) {
 		fprintf(stderr,"gamut map: new_vrml failed for '%s%s'\n","sci_gam_wt",vrm_ext());
Index: trunk/gamut/nearsmth.h
===================================================================
--- trunk.orig/gamut/nearsmth.h
+++ trunk/gamut/nearsmth.h
@@ -274,7 +274,7 @@ gammapweights *src1, double wgt1,
 gammapweights *src2, double wgt2
 );
 
-/* Tweak weights acording to extra cmy cusp flags or rel override */
+/* Tweak weights according to extra cmy cusp flags or rel override */
 void tweak_weights(gammapweights out[14], int dst_cmymap, int rel_oride);
 
 #endif /* NEARSMTH_H */
Index: trunk/imdi/cctiffo.c
===================================================================
--- trunk.orig/imdi/cctiffo.c
+++ trunk/imdi/cctiffo.c
@@ -307,7 +307,7 @@ int pmtc
 		case PHOTOMETRIC_LOGLUV:
 			return "CIELog2Luv";
 	}
-	sprintf(buf,"Unknonw Tag %d",pmtc);
+	sprintf(buf,"Unknown Tag %d",pmtc);
 	return buf;
 }
 
Index: trunk/imdi/greytiff.c
===================================================================
--- trunk.orig/imdi/greytiff.c
+++ trunk/imdi/greytiff.c
@@ -132,7 +132,7 @@ int pmtc
 		case PHOTOMETRIC_LOGLUV:
 			return "CIELog2Luv";
 	}
-	sprintf(buf,"Unknonw Tag %d",pmtc);
+	sprintf(buf,"Unknown Tag %d",pmtc);
 	return buf;
 }
 
Index: trunk/link/collink.c
===================================================================
--- trunk.orig/link/collink.c
+++ trunk/link/collink.c
@@ -1134,7 +1134,7 @@ void devip_devop(void *cntx, double *out
 			}
 			/* We've got the input profile PCS' at this point. */
 
-			/* If we're transfering the K value from the input profile to the */
+			/* If we're transferring the K value from the input profile to the */
 			/* output, copy it into locus[], which will be given to the inverse */
 			/* lookup function, else the inverse lookup will generate a K using */
 			/* the curve parameters. */  
@@ -1265,7 +1265,7 @@ void devip_devop(void *cntx, double *out
 		if (p->nhack == 2) {
 			/* Ideally we would create a 4D PCSK -> PCSK gamut mapping */
 			/* to smoothly and accurately cope with the changing source */
-			/* and destination gamuts acording to their degree of "K onlyness". */
+			/* and destination gamuts according to their degree of "K onlyness". */
 			/* In practice we're going to simply interpolated between */
 			/* two extremes: unrestricted gamut and K only black gamut. */
 			double map0[3], map1[3];
Index: trunk/profile/printcal.c
===================================================================
--- trunk.orig/profile/printcal.c
+++ trunk/profile/printcal.c
@@ -1290,7 +1290,7 @@ int main(int argc, char *argv[]) {
 				icmXYZ2Lab(&wht, wp->Lab, wp->XYZ);
 			}
 
-			/* Sort the channel acording to device value */ 
+			/* Sort the channel according to device value */ 
 			/* For a consistent result for identical device values, */
 			/* secondary sort by inverse CIE value */
 //#define HEAP_COMPARE(A,B) ((A).dev < (B).dev)
Index: trunk/spectro/dispsup.c
===================================================================
--- trunk.orig/spectro/dispsup.c
+++ trunk/spectro/dispsup.c
@@ -707,7 +707,7 @@ static int disprd_read_imp(
 		scb->serno = p->serno++;
 		scb->msec = msec_time();
 
-		a1logd(p->log,1, "got reading %f %f %f, transfering to col\n",
+		a1logd(p->log,1, "got reading %f %f %f, transferring to col\n",
 		                val.XYZ[0], val.XYZ[1], val.XYZ[2]);
 
 		scb->mtype = val.mtype;
Index: trunk/gamut/gammap.c
===================================================================
--- trunk.orig/gamut/gammap.c
+++ trunk/gamut/gammap.c
@@ -775,7 +775,7 @@ gammap *new_gammap(
 #endif
 			if (gmi->bph == gmm_clipBP) {
 
-				/* Extend the target black point to accomodate the */
+				/* Extend the target black point to accommodate the */
 				/* bent or clipped destination space L* range */
 				if (fabp[0] < dr_cs_bp[0]) {
 					t = (fabp[0] - dr_cs_wp[0])/(dr_cs_bp[0] - dr_cs_wp[0]);
Index: trunk/profile/profout.c
===================================================================
--- trunk.orig/profile/profout.c
+++ trunk/profile/profout.c
@@ -1048,7 +1048,7 @@ make_output_icc(
 		if (iccver < icmVersion2_4) {
 			iccver = icmVersion2_4;		/* Need 2.4.0 for Display intents */
 			if (verb)
-				fprintf(verbo,"Bumped ICC version to 2.4.0 to accomodate multiple Display intents\n");
+				fprintf(verbo,"Bumped ICC version to 2.4.0 to accommodate multiple Display intents\n");
 		}
 	}
 	if (wr_icco->set_version(wr_icco, iccver) != 0)
Index: trunk/render/thscreen.c
===================================================================
--- trunk.orig/render/thscreen.c
+++ trunk/render/thscreen.c
@@ -624,7 +624,7 @@ thscreen *new_thscreen(
 	mrang = 65535.0/(t->oelev - 1.0); 
 	DBG(("new_thscreen() raw modulation rande = %f\n",mrang));
 
-	/* Modify the modulation range to accomodate any level overlap */
+	/* Modify the modulation range to accommodate any level overlap */
 	if (olap > 0.0 && t->oelev > 2) {
 		mrang = ((t->oelev - 2.0) * olap * mrang + 65535.0)/(t->oelev - 1.0);
 		DBG(("new_thscreen() modulation adjusted for overlap = %f\n",mrang));
Index: trunk/xicc/xspect.c
===================================================================
--- trunk.orig/xicc/xspect.c
+++ trunk/xicc/xspect.c
@@ -3583,7 +3583,7 @@ void xspect_plot(xspect *sp1, xspect *sp
 /* Given an emission spectrum, set the UV output to the given level. */
 /* The shape of the UV is taken from FWA1_stim, and the level is */
 /* with respect to the Y of the input spectrum. */
-/* The output range is extended to accomodate the UV wavelengths */
+/* The output range is extended to accommodate the UV wavelengths */
 void xsp_setUV(xspect *out, xspect *in, double uvlevel) {
 	int i, xs, xe;
 	double ww, avg;
Index: trunk/spectro/dispwin.c
===================================================================
--- trunk.orig/spectro/dispwin.c
+++ trunk/spectro/dispwin.c
@@ -2734,7 +2734,7 @@ int dispwin_install_profile(dispwin *p,
 
 /* Un-Install a display profile */
 /* Return nz if failed, */
 /* 1 if not sucessfully deleted */
 /* 2 if profile not found */
 int dispwin_uninstall_profile(dispwin *p, char *fname, p_scope scope) {
 	debugr2((errout,"dispwin_uninstall_profile '%s'\n", fname));
@@ -5123,7 +5123,7 @@ int ddebug						/* >0 to print debug sta
 		p->native = native &= ~2;
 	}
 
-	debugr("new_dispwin: return sucessfully\n");
+	debugr("new_dispwin: return successfully\n");
 	return p;
 }
 
@@ -2734,7 +2734,7 @@ int dispwin_install_profile(dispwin *p,
 /* Un-Install a display profile */
 /* Return nz if failed, */
-/* 1 if not sucessfully deleted */
+/* 1 if not successfully deleted */
 /* 2 if profile not found */
 int dispwin_uninstall_profile(dispwin *p, char *fname, p_scope scope) {